@@ -1110,14 +1110,18 @@ poppler_page_render_to_ps (PopplerPage   *page,
   g_return_if_fail (POPPLER_IS_PAGE (page));
   g_return_if_fail (ps_file != NULL);
 
-  if (!ps_file->out)
+  if (!ps_file->out)  {
+    std::vector<int> pages;
+    for (int i = ps_file->first_page; i <= ps_file->last_page; ++i) {
+      pages.push_back(i);
+    }
     ps_file->out = new PSOutputDev (ps_file->filename,
                                     ps_file->document->doc,
-                                    NULL,
-                                    ps_file->first_page, ps_file->last_page,
+                                    NULL, pages,
                                     psModePS, (int)ps_file->paper_width,
                                     (int)ps_file->paper_height, ps_file->duplex,
                                     0, 0, 0, 0, gFalse, gFalse);
+  }
 
 
   ps_file->document->doc->displayPage (ps_file->out, page->index + 1, 72.0, 72.0,
